/* dialog.cpp
 *
 * Pieter Eendebak <pte@ddsw.nl>
 *
 */

#include "includes.h"
#include "defines.h"

#include "dialog.moc"

/* ##########################
 * #    class Misc                      #
 * ##########################
 */

Misc::Misc ( int _sound, int _pixmaps, QWidget *parent, const char *name )
                : QDialog ( parent, name, TRUE )
{
	setCaption(CAPTION);
	setMinimumSize(200,200);

	const int breed=300;
	const int hoog=250;
	const int bbreed=breed-20;
	const int bhoog=hoog-60;
	// should be removed when resizing is ok...
	setFixedSize(breed, hoog);

	box = new QGroupBox(klocale->translate("Misc options"),
			this,
			"box" );

	sound = new QCheckBox(klocale->translate("Play sounds"),
			box,
			"sound" );
	sound->setChecked(  _sound==1 );

	pixmaps = new QCheckBox(klocale->translate("Use pixmaps"),
			box,
			"pixmaps" );
	pixmaps->setChecked( _pixmaps==1 );

	ok = new QPushButton(klocale->translate("Ok"), this, "ok");
	cancel = new QPushButton(klocale->translate("Cancel"),
			 this,
			 "cancel");
	connect(ok, SIGNAL(clicked()), this, SLOT(accept()) );
	connect(cancel, SIGNAL(clicked()), this, SLOT(reject()) );

	box->setGeometry(10,10, bbreed, bhoog);

	sound->setGeometry ( 10, 20, bbreed-20, 30 );
	pixmaps->setGeometry ( 10, 60, bbreed-20, 30 );

	ok->setGeometry(breed-160, hoog-40, 70, 30);
	cancel->setGeometry(breed-80, hoog-40, 70, 30);

}

Misc::~Misc()
{
	delete sound;
	delete pixmaps;

	delete ok;
	delete cancel;
}

/* ##########################
 * #	class NoCode        #
 * ##########################
 */

NoCode::NoCode ( QWidget *parent, const char *name, int *code, int len,
		bool pixmaps, QPixmap **pins, const char * _base )
		: QDialog ( parent, name, TRUE )
{
	setCaption(CAPTION);
	const int breed=260;
	const int hoog=180;

	setFixedSize(breed,hoog);
	
	aantal=len;	

	QString q;
	q.sprintf( klocale->translate("You didn't guess the secret"
			"code !\nThe secret code was : ") );
	tekst = new QLabel(this);
	tekst->setText(q);
	
	knoppen = new Knop *[aantal];
	for (int i=0;i<aantal;i++)
	{
		knoppen[i] = new Knop(pixmaps, pins, _base, this);	
		knoppen[i]->setColor(code[i]);
	}
	
	ok = new QPushButton( klocale->translate("Ok"), this);	
	connect(ok, SIGNAL(clicked()), this, SLOT(accept()) );

	tekst->show();
	ok->show();

	tekst->setGeometry( 10, 10, breed-20, 50);
	
	if (pixmaps)
	{
		int k = (int)((breed-aantal*30)/2);

		for (int i=0;i<aantal;i++)
		{
			knoppen[i]->show();
			knoppen[i]->setGeometry(k+i*30, 70, 30, 30);
		}
	}
	else
	{
		int k = breed/(aantal+1);
		for (int i=0;i<aantal;i++)
		{
			knoppen[i]->show();
			knoppen[i]->setGeometry(k*(i+1)-10, 70, 20, 20);
		}
	}
	ok->setGeometry( (breed/2)-30, 120, 60, 40);
}

NoCode::~NoCode()
{
	delete tekst;
	delete [] knoppen;
	delete ok;
}

/* ##########################
 * #	class CustomLevel   #
 * ##########################
 */

CustomLevel::CustomLevel ( QWidget *parent, const char *name )
		: QDialog ( parent, name, TRUE )
{
	setCaption(CAPTION);
	const int breed=260;
	const int hoog=230;
	const int bbreed=240;
	const int bhoog=170;
	setFixedSize(breed, hoog);
	
	box = new QGroupBox(klocale->translate("Custom level"), this, "box");
	
	rowscrol = new QScrollBar(2, 15, 1, 1, 10,
		 QScrollBar::Horizontal, box, "rowscrol");
	rowlabel = new QLabel(klocale->translate("Number of rows :"),
				 box, "rlabel");
	rowcounter = new QLabel( "10", box, "rowcounter");
	rowcounter->setFrameStyle( QFrame::Panel | QFrame::Sunken);
	rowcounter->setAlignment(AlignCenter);	

	levelscrol = new QScrollBar(2, 10, 1, 1, 4, QScrollBar::Horizontal, box, "levelscrol");
	levellabel = new QLabel(klocale->translate("Number of slots : "),
				 box, "llabel");
	levelcounter = new QLabel("4", box, "levelcounter");
	levelcounter->setFrameStyle( QFrame::Panel | QFrame::Sunken);
	levelcounter->setAlignment(AlignCenter);	
	
	ok = new QPushButton(klocale->translate("Ok"), this, "ok");
	cancel = new QPushButton("Cancel", this, "cancel");
	connect(ok, SIGNAL(clicked()), this, SLOT(accept()) );
	connect(cancel, SIGNAL(clicked()), this, SLOT(reject()) );

	box->setGeometry(10,10, bbreed, bhoog);
	
	levellabel->setGeometry( 10, 20, 100, 25);
	levelscrol->setGeometry( 10, 50, bbreed-20, 15);
	levelcounter->setGeometry ( bbreed-30, 20, 20, 20);
	connect( levelscrol, SIGNAL(valueChanged(int)),
		 this, SLOT(levelchange(int)) );

	rowlabel->setGeometry( 10, 90, 100, 25);
	rowscrol->setGeometry( 10, 120, bbreed - 20, 15);
	rowcounter->setGeometry ( bbreed-30, 90, 20, 20);
	connect( rowscrol, SIGNAL(valueChanged(int)),
		 this, SLOT(rowchange(int)) );


	ok->setGeometry(breed-120, hoog-40, 50, 30);
	cancel->setGeometry(breed-60, hoog-40, 50, 30);

	rows=10; level=4;
}

void CustomLevel::rowchange(int _rows)
{
	rows=_rows;
	rowcounter->setNum(rows);
}

void CustomLevel::levelchange(int _level)
{
	level=_level;
	levelcounter->setNum(level);
}


CustomLevel::~CustomLevel()
{
	delete rowlabel;
	delete levellabel;
	delete rowscrol;
	delete levelscrol;
	delete rowcounter;
	delete levelcounter;

	delete box;

	delete ok;
	delete cancel;
}


/* ##########################
 * #	class CreateColors  #
 * ##########################
 */

CreateColors::CreateColors ( QWidget *parent, const char *name )
			: QDialog ( parent, name, TRUE )
{
	// this is quite a problem as the classes Knop & MasterRow
	// use int as a type for representing colors...
}

CreateColors::~CreateColors()
{
}

